@@ -204,10 +204,10 @@ class API(metaclass=Singleton):
         while(current_page < total_pages):
             current_page += 1
             status, response = self.__get_user_segments_mapping_page(
-                page=current_page,
-                limit=10000,
                 fields=fields,
                 token=token
+                page=current_page,
+                limit=10000,
             )
             segments += response['docs']
             total_pages = response['pages']
@@ -215,7 +215,7 @@ class API(metaclass=Singleton):
         return segments
 
 
-    def __get_user_segments_mapping_page(page=current_page, limit=10000, fields, token):
+    def __get_user_segments_mapping_page(fields, token, page=current_page, limit=10000):
         path = self.url + '/api/v2/segments/user_segments/mapping'
         session = self.__build_session(token)
         params = {
